@@ -59,8 +59,6 @@ sub addNews {
             && defined param('catlist')) {
             my $message = param('message');
 
-            #             my $max = $m_hrSettings->{news}{maxlength} < 32766 ? $m_hrSettings->{news}{maxlength} : 0;
-            #             $message = ($message =~ /^(.{3,$max})$/s) ? $1 : translate('invalidBody') if $max > 0;
             my $headline = param('headline');
             $headline = ($headline =~ /^(.{3,100})$/s) ? $1 : translate('invalidHeadline');
             my $thread = param('thread');
@@ -210,9 +208,7 @@ sub replyNews {
     my $th = param('thread');
     $th = ($th =~ /^(\w+)$/) ? $1 : 'news';
     my $attachment;
-    if ($m_nRight >= 2) {
-        $attachment = $m_hrSettings->{uploads}{enabled};
-    } else {
+    if ($m_nRight <= 2){
         eval('
         use Authen::Captcha;
         my $captcha = Authen::Captcha->new(
@@ -229,8 +225,6 @@ sub replyNews {
         body   => translate('insertText'),
         class  => 'max',
         attach => $attachment,
-
-        #                      maxlength => $m_hrSettings->{news}{maxlength},
         path     => "$m_hrSettings->{cgi}{bin}/templates",
         reply    => $id,
         server   => $m_hrSettings->{cgi}{serverName},
@@ -241,8 +235,7 @@ sub replyNews {
         right    => $m_nRight,
         catlist  => '',
         html     => 0,
-        atemp =>
-          qq(<input  name="von" value="$m_nStart" style="display:none;"/><input  name="bis" value="$m_nEnd" style="display:none;"/>),
+        atemp     => qq(<input  name="von" value="$m_nStart" style="display:none;"/><input  name="bis" value="$m_nEnd" style="display:none;"/>),
     );
     my $editor = new HTML::Editor(\%parameter);
     print '<div align="center"><br/>';
@@ -261,14 +254,15 @@ sub addReply {
         $format = 'html' if param('format') eq 'on';
     }
     my $result = 0;
-    if ($m_nRight < 2) {
+    if ($m_nRight <= 2) {
         eval('
         use Authen::Captcha;
         my $captcha = Authen::Captcha->new(data_folder   => "$m_hrSettings->{cgi}{bin}/config/",
                                            output_folder => "$m_hrSettings->{cgi}{DocumentRoot}/images");
         $result = $captcha->check_code(param("captcha"), param("md5"));');
         $result = 1 if $@;    # skip captcha without gd
-    } else {
+    }
+    else {
         $result = 1;
     }
     print div({align => 'center'}, translate('Codenotchecked'))      if $result eq 0;
@@ -290,6 +284,7 @@ sub addReply {
                          user   => $m_sUser,
                          attach => $sra,
                          format => $format,
+			 ip => remote_addr(),
                         );
             $m_oDatabase->reply(\%reply);
         } else {
@@ -299,6 +294,7 @@ sub addReply {
                          id     => $reply,
                          user   => $m_sUser,
                          format => $format,
+                         ip => remote_addr(),
                         );
             $m_oDatabase->reply(\%reply);
         }
@@ -470,7 +466,6 @@ sub preview {
     print '<br/>';
     my $html = defined param('format') ? param('format') : 'off';
     $html = $html eq 'on' ? 1 : 0;
-#     utf8::decode($body) unless (utf8::is_utf8($body));
     unless ($html) {
         BBCODE(\$body);
     } else {
@@ -482,11 +477,9 @@ sub preview {
       qq(<table class="ShowTables" style="padding:1%;"><tr><td class="headline">$headline</td></tr><tr><td align="left">$body</td></tr></table>);
     my $attachment;
 
-    if ($m_nRight >= $m_hrSettings->{news}{uploadright}) {
-        $attachment = $m_hrSettings->{uploads}{enabled};
-    } else {
+    if ($m_nRight <=2){
         eval(
-            qq?
+            q?
 	use Authen::Captcha;
         my $captcha = Authen::Captcha->new(
                                            data_folder   => "$m_hrSettings->{cgi}{bin}/config/",
@@ -498,13 +491,12 @@ sub preview {
         ?
             );
     }
+
     my %parameter = (
         action => $m_sAction,
         body   => param('message'),
         class  => 'max',
         attach => $attachment,
-
-        #                      maxlength => $m_hrSettings->{news}{maxlength},
         path     => "$m_hrSettings->{cgi}{bin}/templates",
         reply    => $id,
         server   => $m_hrSettings->{cgi}{serverName},
@@ -646,12 +638,6 @@ sub threadBody {
         $sth->execute() or warn $m_dbh->errstr;
         return '' if $m_dbh->errstr;
         while (my @data = $sth->fetchrow_array()) {
-
-            # 	  for (my $i =1; $i <= $#data; $i++) {
-            # 	    unless ( utf8::is_utf8(  $data[$i] ) ){
-            # 		  utf8::decode(  $data[$i]  );
-            # 	    }
-            # 	    }
             my $headline    = $data[0];
             my $body        = $data[1];
             my $date        = $data[2];
@@ -707,8 +693,7 @@ sub threadBody {
             my $h1       = qq(<tr id="trw$id"><td valign="top">);
             my $readmore = translate('readmore');
             $reply .= qq( <a href="$replylink" class="link" >$readmore</a>)
-              if $body =~ /\[previewende\]/i && $thread eq 'news';
-# 	    utf8::decode($body) unless utf8::is_utf8($body);
+            if $body =~ /\[previewende\]/i && $thread eq 'news';
             if ($th eq 'news') {
                 if ($ACCEPT_LANGUAGE eq 'de') {
                     $body =~ s/\[en\](.*?)\[\/en\]//gs;
