@@ -1,59 +1,59 @@
 $VAR1 = {
-          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'translate' => '/var/www/cgi-bin/config/translate.pl',
+          'admin' => {
+                       'password' => 'testpass'
+                     },
           'htmlright' => '2',
-          'actions' => '/var/www/cgi-bin/config/actions.pl',
+          'language' => 'en',
+          'news' => {
+                      'right' => 5,
+                      'captcha' => 3,
+                      'messages' => '5'
+                    },
+          'session' => '/var/www/cgi-bin/config/session.pl',
           'floodtime' => 10,
+          'apacheconfig' => '/etc/apache2/sites-enabled/',
           'tree' => {
                       'links' => '/var/www/cgi-bin/config/links.pl',
                       'navigation' => '/var/www/cgi-bin/config/tree.pl'
                     },
           'files' => {
                        'owner' => 'lze',
-                       'group' => 'lze',
-                       'chmod' => '0755'
+                       'chmod' => '0755',
+                       'group' => 'lze'
                      },
-          'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'size' => '16',
-          'saveTranslate' => '0',
-          'defaultAction' => 'ShowDatabases',
-          'session' => '/var/www/cgi-bin/config/session.pl',
-          'language' => 'en',
-          'news' => {
-                      'captcha' => 3,
-                      'messages' => '5',
-                      'right' => 5
-                    },
-          'database' => {
-                          'user' => 'root',
-                          'name' => 'MySQLAdmin',
-                          'CurrentHost' => 'localhost',
-                          'CurrentUser' => 'root',
-                          'CurrentDb' => 'MySQLAdmin',
-                          'password' => '',
-                          'host' => 'localhost',
-                          'CurrentPass' => ''
-                        },
           'cgi' => {
-                     'title' => 'MySQL::Admin',
-                     'DocumentRoot' => '/var/www/htdocs/',
-                     'serverName' => 'http://localhost',
-                     'expires' => '+1y',
                      'bin' => '/var/www/cgi-bin',
-                     'style' => 'mysql',
-                     'cookiePath' => '/'
+                     'serverName' => 'http://localhost',
+                     'DocumentRoot' => '/var/www/htdocs/',
+                     'cookiePath' => '/',
+                     'expires' => '+1y',
+                     'title' => 'MySQL::Admin',
+                     'style' => 'mysql'
                    },
-          'version' => '0.96',
-          'apacheconfig' => '/etc/apache2/sites-enabled/',
-          'uploads' => {
-                         'enabled' => 1,
-                         'chmod' => 438,
-                         'maxlength' => '2100000000000000',
-                         'path' => '/var/www/htdocs//download',
-                         'right' => 2
-                       },
+          'database' => {
+                          'host' => 'localhost',
+                          'user' => 'root',
+                          'password' => '',
+                          'CurrentUser' => 'root',
+                          'CurrentPass' => '',
+                          'CurrentHost' => 'localhost',
+                          'CurrentDb' => 'MySQLAdmin',
+                          'name' => 'MySQLAdmin'
+                        },
+          'config' => '/var/www/cgi-bin/config/settings.pl',
+          'actions' => '/var/www/cgi-bin/config/actions.pl',
           'mod' => 'n',
-          'admin' => {
-                       'password' => 'testpass'
-                     }
+          'size' => '16',
+          'version' => '0.97',
+          'uploads' => {
+                         'chmod' => 438,
+                         'right' => 2,
+                         'enabled' => 1,
+                         'path' => '/var/www/htdocs//download',
+                         'maxlength' => '2100000000000000'
+                       },
+          'saveTranslate' => '0',
+          'defaultAction' => 'ShowDatabases'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
